@@ -8,7 +8,7 @@ use 5.006;
 use Math::BigInt;
 use Tie::Simple;
 
-our $VERSION = '0.14';
+our $VERSION = '0.15';
 
 our $IP_NO_OVERLAP      = 0;
 our $IP_PARTIAL_OVERLAP = 1;
@@ -179,33 +179,6 @@ sub ip_auth
     return ($reg->inet_atoauth($ip));
 }
 
-sub STORABLE_freeze
-{
-    my ($self, $cloning) = @_;
-
-    my %copy = %{$self};
-    delete @copy{qw(xs_v6_ip0 xs_v6_ip1)};
-
-    return (1, \%copy);
-}
-
-sub STORABLE_thaw
-{
-    my ($self, $cloning, $dummy, $copy) = @_;
-
-    my @fields = keys %{$copy};
-    @{$self}{@fields} = @{$copy}{@fields};
-
-    if ($self->{'ipversion'} == 6) {
-        my $res = $self->set_ipv6_n128s();
-        if (!$res) {
-            die "Unable to generate internal IPv6 bignums.";
-        }
-    }
-    
-    return $copy;
-}
-
 1;
 
 __END__
@@ -395,7 +368,7 @@ L<Net::IP|Net::IP>, L<IP::Authority|IP::Authority>.
 
 =head1 COPYRIGHT & LICENSE
 
-Copyright (C) 2010-2014 Tom Harrison <tomhrr@cpan.org>.
+Copyright (C) 2010-2015 Tom Harrison <tomhrr@cpan.org>.
 
 Original inet_pton4 and inet_pton6 functions are copyright (C) 2006 
 Free Software Foundation.
